==> jaxb2-rich-contract-plugin-1.17.0.jar: com/kscs/util/jaxb/SingleProperty.java <==
/*
 * MIT License
 *
 * Copyright (c) 2014 Klemm Software Consulting, Mirko Klemm
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.kscs.util.jaxb;

/**
 * @author Mirko Klemm 2015-10-16
 */
public class SingleProperty<I,P> extends Property<I,P> {

	public SingleProperty(final SinglePropertyInfo<I, P> info, final I owner) {
		super(info, owner);
	}

	@Override
	public SinglePropertyInfo<I, P> getInfo() {
		return (SinglePropertyInfo<I, P>)super.getInfo();
	}

	@Override
	public P get() {
		return (P)super.get();
	}

	public void set(final P value) {
		getInfo().set(getOwner(), value);
	}
}

==> jaxb2-rich-contract-plugin-2.0.1.jar: com/kscs/util/jaxb/SingleProperty.java <==
/*
 * MIT License
 *
 * Copyright (c) 2014 Klemm Software Consulting, Mirko Klemm
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.kscs.util.jaxb;

/**
 * Represents the instance of a {@link SinglePropertyInfo}, i.e. represents the
 * property meta information along with its value, and enables to get an d set the value
 */
public class SingleProperty<I,P> extends Property<I,P> {

	public SingleProperty(final SinglePropertyInfo<I, P> info, final I owner) {
		super(info, owner);
	}

	@Override
	public SinglePropertyInfo<I, P> getInfo() {
		return (SinglePropertyInfo<I, P>)super.getInfo();
	}

	@Override
	public P get() {
		return (P)super.get();
	}

	public void set(final P value) {
		getInfo().set(getOwner(), value);
	}
}
